Index: tmp/org.txm.setups/.settings/org.eclipse.core.resources.prefs
===================================================================
--- tmp/org.txm.setups/.settings/org.eclipse.core.resources.prefs	(revision 1219)
+++ tmp/org.txm.setups/.settings/org.eclipse.core.resources.prefs	(revision 1220)
@@ -1,3 +1,6 @@
 eclipse.preferences.version=1
+encoding//shared/mac/finish_fr.txt=MacRoman
+encoding//shared/mac/intro_fr.txt=MacRoman
+encoding//shared/mac/readme_fr.txt=MacRoman
 encoding//shared/win/txm.nsi=ISO-8859-1
 encoding/SetupMessages_fr.properties=UTF-8
Index: tmp/org.txm.setups/shared/mac/intro_en.txt
===================================================================
--- tmp/org.txm.setups/shared/mac/intro_en.txt	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/intro_en.txt	(revision 1220)
@@ -5,4 +5,4 @@
 
 TXM will install R Packages, this default behavior can be changed during installation.
 
-Minimum requirements: MAC OS X 10.6
\ No newline at end of file
+Minimum requirements: MAC OS X 10.10
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/01applications.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/01applications.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/01applications.xml	(revision 1220)
@@ -1 +1,58 @@
-<pkgref spec="1.12" uuid="010E4888-F605-4E8A-BAA6-15FAE49B744F"><config><identifier>org.txm.txm071.Applications.pkg</identifier><version>1.0</version><description></description><post-install type="none"/><requireAuthorization/><installFrom relative="true" mod="true">Applications</installFrom><installTo mod="true">/Applications</installTo><flags><followSymbolicLinks/></flags><packageStore type="internal"></packageStore><mod>installTo</mod><mod>installFrom.path</mod><mod>scripts.preinstall.isRelativeType</mod><mod>identifier</mod><mod>parent</mod><mod>installTo.path</mod><mod>scripts.postinstall.isRelativeType</mod><mod>installFrom.isRelativeType</mod></config><scripts><preinstall relative="true" mod="true">CLEAN</preinstall><postinstall relative="true" mod="true">INSTALL</postinstall></scripts><contents><component id="org.eclipse.eclipse" path="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/Applications/TXM/.main.app" version="4.4"/><component id="appified.mdecorde.TXM" path="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/Applications/TXM/TXM.app" version="0.1"/><filter>/CVS$</filter><filter>/\.svn$</filter><filter>/\.cvsignore$</filter><filter>/\.cvspass$</filter><filter>/\.DS_Store$</filter></contents></pkgref>
\ No newline at end of file
+
+<pkgref spec="1.12" uuid="010E4888-F605-4E8A-BAA6-15FAE49B744F">
+<config>
+<identifier>org.txm.txm071.Applications.pkg
+</identifier>
+<version>1.0
+</version>
+<description>
+</description>
+<post-install type="none"/>
+<requireAuthorization/>
+<installFrom relative="true" mod="true">Applications
+</installFrom>
+<installTo mod="true">/Applications
+</installTo>
+<flags>
+<followSymbolicLinks/>
+</flags>
+<packageStore type="internal">
+</packageStore>
+<mod>installTo
+</mod>
+<mod>installFrom.path
+</mod>
+<mod>scripts.preinstall.isRelativeType
+</mod>
+<mod>identifier
+</mod>
+<mod>parent
+</mod>
+<mod>installTo.path
+</mod>
+<mod>scripts.postinstall.isRelativeType
+</mod>
+<mod>installFrom.isRelativeType
+</mod>
+</config>
+<scripts>
+<preinstall relative="true" mod="true">CLEAN
+</preinstall>
+<postinstall relative="true" mod="true">INSTALL
+</postinstall>
+</scripts>
+<contents>
+<component id="org.eclipse.eclipse" path="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/Applications/TXM-TXMVERSION.app" version="4.4"/>
+<component id="appified.mdecorde.TXM" path="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/Applications/TXM-TXMVERSION.app" version="0.1"/>
+<filter>/CVS$
+</filter>
+<filter>/\.svn$
+</filter>
+<filter>/\.cvsignore$
+</filter>
+<filter>/\.cvspass$
+</filter>
+<filter>/\.DS_Store$
+</filter>
+</contents>
+</pkgref>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/index.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/index.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/index.xml	(revision 1220)
@@ -1 +1,67 @@
-<pkmkdoc spec="1.12"><properties><title>TXM 0.8.0</title><build>/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX.pkg</build><organization>org.txm</organization><userSees ui="both"/><min-target os="3"/><domain anywhere="true"/></properties><distribution><versions min-spec="1.000000"/><scripts></scripts></distribution><contents><choice title="Applications" id="choice110" starts_selected="true" starts_enabled="false" starts_hidden="true"><pkgref id="org.txm.txm071.Applications.pkg"/></choice><choice title="R packages" id="choice129" tooltip="install R packages needed: 'Rserve', 'lattice', 'cluster', 'scatterplot3d', 'factomineR' and 'textometry'." description="If you don't select that option, please install these packages manually before using TXM. See FAQ: https://groupes.renater.fr/wiki/txm-users/public/faq#installation_mac_os_x_le_moteur_de_statistique_r_ne_demarre_pas" starts_selected="true" starts_enabled="true" starts_hidden="false"><pkgref id="org.txm.txm078.rlibs.pkg"/></choice><choice title="opt" id="choice123" starts_selected="true" starts_enabled="false" starts_hidden="true"><pkgref id="org.txm.txm078.opt.pkg"/></choice></contents><resources bg-scale="proportional" bg-align="center"><locale lang="fr"><resource relative="true" mod="true" type="background">background.jpg</resource><resource relative="true" mod="true" type="license">Applications/TXM/license_agreement_fr.txt</resource><resource relative="true" mod="true" type="readme">readme_fr.txt</resource><resource relative="true" mod="true" type="welcome">intro_fr.txt</resource><resource relative="true" mod="true" type="conclusion">finish_fr.txt</resource></locale><locale lang="en"><resource relative="true" mod="true" type="background">background.jpg</resource><resource relative="true" mod="true" type="license">Applications/TXM/license_agreement.txt</resource><resource relative="true" mod="true" type="readme">readme_en.txt</resource><resource relative="true" mod="true" type="welcome">intro_en.txt</resource><resource relative="true" mod="true" type="conclusion">finish_en.txt</resource></locale></resources><flags/><item type="file">01applications.xml</item><item type="file">02rlibs.xml</item><item type="file">03opt.xml</item><mod>properties.title</mod><mod>properties.systemDomain</mod></pkmkdoc>
\ No newline at end of file
+
+<pkmkdoc spec="1.12">
+<properties>
+<title>TXM TXMVERSION
+</title>
+<build>/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX.pkg
+</build>
+<organization>org.txm
+</organization>
+<userSees ui="both"/>
+<min-target os="3"/>
+<domain anywhere="true"/>
+</properties>
+<distribution>
+<versions min-spec="1.000000"/>
+<scripts>
+</scripts>
+</distribution>
+<contents>
+<choice title="Applications" id="choice110" starts_selected="true" starts_enabled="false" starts_hidden="true">
+<pkgref id="org.txm.txm071.Applications.pkg"/>
+</choice>
+<choice title="R packages" id="choice129" tooltip="install R packages needed: 'Rserve', 'lattice', 'cluster', 'scatterplot3d', 'factomineR' and 'textometry'." description="If you don't select that option, please install these packages manually before using TXM TXMVERSION. See FAQ: https://groupes.renater.fr/wiki/txm-users/public/faq#installation_mac_os_x_le_moteur_de_statistique_r_ne_demarre_pas" starts_selected="true" starts_enabled="true" starts_hidden="false">
+<pkgref id="org.txm.txm078.rlibs.pkg"/>
+</choice>
+<choice title="opt" id="choice123" starts_selected="true" starts_enabled="false" starts_hidden="true">
+<pkgref id="org.txm.txm078.opt.pkg"/>
+</choice>
+</contents>
+<resources bg-scale="proportional" bg-align="center">
+<locale lang="fr">
+<resource relative="true" mod="true" type="background">background.jpg
+</resource>
+<resource relative="true" mod="true" type="license">Applications/TXM-TXMVERSION.app/Contents/TXM/license_agreement_fr.txt
+</resource>
+<resource relative="true" mod="true" type="readme">readme_fr.txt
+</resource>
+<resource relative="true" mod="true" type="welcome">intro_fr.txt
+</resource>
+<resource relative="true" mod="true" type="conclusion">finish_fr.txt
+</resource>
+</locale>
+<locale lang="en">
+<resource relative="true" mod="true" type="background">background.jpg
+</resource>
+<resource relative="true" mod="true" type="license">Applications/TXM-TXMVERSION.app/Contents/TXM/license_agreement.txt
+</resource>
+<resource relative="true" mod="true" type="readme">readme_en.txt
+</resource>
+<resource relative="true" mod="true" type="welcome">intro_en.txt
+</resource>
+<resource relative="true" mod="true" type="conclusion">finish_en.txt
+</resource>
+</locale>
+</resources>
+<flags/>
+<item type="file">01applications.xml
+</item>
+<item type="file">02rlibs.xml
+</item>
+<item type="file">03opt.xml
+</item>
+<mod>properties.title
+</mod>
+<mod>properties.systemDomain
+</mod>
+</pkmkdoc>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs-contents.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs-contents.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs-contents.xml	(revision 1220)
@@ -1 +1,4 @@
-<pkg-contents spec="1.12"><f n="rlibs.R" o="mdecorde" g="staff" p="33188" pt="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/Applications/TXM/R/rlibs.R" m="false" t="file"/></pkg-contents>
\ No newline at end of file
+
+<pkg-contents spec="1.12">
+<f n="rlibs.R" o="mdecorde" g="staff" p="33188" pt="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/Applications/TXM-TXMVERSION.app/Contents/TXM/R/rlibs.R" m="false" t="file"/>
+</pkg-contents>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03rlibs-contents.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03rlibs-contents.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03rlibs-contents.xml	(revision 1220)
@@ -1 +1,4 @@
-<pkg-contents spec="1.12"><f n="rlibs.R" o="mdecorde" g="staff" p="33188" pt="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/Applications/TXM/R/rlibs.R" m="false" t="file"/></pkg-contents>
\ No newline at end of file
+
+<pkg-contents spec="1.12">
+<f n="rlibs.R" o="mdecorde" g="staff" p="33188" pt="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/Applications/TXM-TXMVERSION.app/Contents/TXM/R/rlibs.R" m="false" t="file"/>
+</pkg-contents>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02rlibs.xml	(revision 1220)
@@ -1 +1,44 @@
-<pkgref spec="1.12" uuid="627D63FB-F669-4740-A45E-20CCE6883109"><config><identifier>org.txm.txm078.rlibs.pkg</identifier><version>1.0</version><description></description><post-install type="none"/><requireAuthorization/><installFrom relative="true" mod="true">Applications/TXM/R/rlibs.R</installFrom><installTo mod="true">/Applications/TXM/R</installTo><flags><followSymbolicLinks/></flags><packageStore type="internal"></packageStore><mod>installTo.path</mod><mod>installFrom.path</mod><mod>parent</mod><mod>installTo</mod></config><contents><file-list>02rlibs-contents.xml</file-list><filter>/CVS$</filter><filter>/\.svn$</filter><filter>/\.cvsignore$</filter><filter>/\.cvspass$</filter><filter>/\.DS_Store$</filter></contents></pkgref>
\ No newline at end of file
+
+<pkgref spec="1.12" uuid="627D63FB-F669-4740-A45E-20CCE6883109">
+<config>
+<identifier>org.txm.txm078.rlibs.pkg
+</identifier>
+<version>1.0
+</version>
+<description>
+</description>
+<post-install type="none"/>
+<requireAuthorization/>
+<installFrom relative="true" mod="true">Applications/TXM-TXMVERSION.app/R/rlibs.R
+</installFrom>
+<installTo mod="true">/Applications/TXM-TXMVERSION.app/Contents/TXM/R
+</installTo>
+<flags>
+<followSymbolicLinks/>
+</flags>
+<packageStore type="internal">
+</packageStore>
+<mod>installTo.path
+</mod>
+<mod>installFrom.path
+</mod>
+<mod>parent
+</mod>
+<mod>installTo
+</mod>
+</config>
+<contents>
+<file-list>02rlibs-contents.xml
+</file-list>
+<filter>/CVS$
+</filter>
+<filter>/\.svn$
+</filter>
+<filter>/\.cvsignore$
+</filter>
+<filter>/\.cvspass$
+</filter>
+<filter>/\.DS_Store$
+</filter>
+</contents>
+</pkgref>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02opt-contents.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02opt-contents.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/02opt-contents.xml	(revision 1220)
@@ -1 +1,61 @@
-<pkg-contents spec="1.12"><f n="opt" o="mdecorde" g="staff" p="16877" pt="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/opt" m="false" t="file"><f n="local" o="mdecorde" g="staff" p="16877"><f n="lib" o="mdecorde" g="staff" p="16877"><f n="libasprintf.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libasprintf.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.0.6.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libexpat.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libexpat.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextlib-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextlib.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextpo.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextpo.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextsrc-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextsrc.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgio-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgio-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libglib-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libglib-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgmodule-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgmodule-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgobject-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgobject-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgthread-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgthread-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.dylib" o="mdecorde" g="staff" p="33188"/><f n="libiconv.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libiconv.dylib" o="mdecorde" g="staff" p="33188"/><f n="libintl.8.dylib" o="mdecorde" g="staff" p="33188"/><f n="libintl.dylib" o="mdecorde" g="staff" p="33188"/><f n="liblzma.5.dylib" o="mdecorde" g="staff" p="33188"/><f n="liblzma.dylib" o="mdecorde" g="staff" p="33188"/><f n="libncurses.5.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcrecpp.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcrecpp.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcreposix.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcreposix.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.dylib" o="mdecorde" g="staff" p="33188"/></f></f></f></pkg-contents>
\ No newline at end of file
+
+<pkg-contents spec="1.12">
+<f n="opt" o="mdecorde" g="staff" p="16877" pt="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/opt" m="false" t="file">
+<f n="local" o="mdecorde" g="staff" p="16877">
+<f n="lib" o="mdecorde" g="staff" p="16877">
+<f n="libasprintf.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libasprintf.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.0.6.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libexpat.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libexpat.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextlib-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextlib.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextpo.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextpo.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextsrc-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextsrc.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgio-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgio-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libglib-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libglib-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgmodule-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgmodule-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgobject-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgobject-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgthread-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgthread-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libiconv.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libiconv.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libintl.8.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libintl.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="liblzma.5.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="liblzma.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libncurses.5.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcrecpp.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcrecpp.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcreposix.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcreposix.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.dylib" o="mdecorde" g="staff" p="33188"/>
+</f>
+</f>
+</f>
+</pkg-contents>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03opt-contents.xml
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03opt-contents.xml	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pmdoc/03opt-contents.xml	(revision 1220)
@@ -1 +1,61 @@
-<pkg-contents spec="1.12"><f n="opt" o="mdecorde" g="staff" p="16877" pt="/Users/mdecorde/Desktop/TXM_0.8.0_MacOSX/opt" m="false" t="file"><f n="local" o="mdecorde" g="staff" p="16877"><f n="lib" o="mdecorde" g="staff" p="16877"><f n="libasprintf.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libasprintf.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.0.6.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libbz2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libexpat.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libexpat.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextlib-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextlib.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextpo.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextpo.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextsrc-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgettextsrc.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgio-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgio-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libglib-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libglib-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgmodule-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgmodule-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgobject-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgobject-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgthread-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libgthread-2.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.5.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libhistory.6.dylib" o="mdecorde" g="staff" p="33188"/><f n="libiconv.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libiconv.dylib" o="mdecorde" g="staff" p="33188"/><f n="libintl.8.dylib" o="mdecorde" g="staff" p="33188"/><f n="libintl.dylib" o="mdecorde" g="staff" p="33188"/><f n="liblzma.5.dylib" o="mdecorde" g="staff" p="33188"/><f n="liblzma.dylib" o="mdecorde" g="staff" p="33188"/><f n="libncurses.5.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcre.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcrecpp.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcrecpp.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcreposix.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libpcreposix.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.0.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.5.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.1.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.2.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.3.dylib" o="mdecorde" g="staff" p="33188"/><f n="libreadline.6.dylib" o="mdecorde" g="staff" p="33188"/></f></f></f></pkg-contents>
\ No newline at end of file
+
+<pkg-contents spec="1.12">
+<f n="opt" o="mdecorde" g="staff" p="16877" pt="/Users/mdecorde/Desktop/TXM_TXMVERSION_MacOSX/opt" m="false" t="file">
+<f n="local" o="mdecorde" g="staff" p="16877">
+<f n="lib" o="mdecorde" g="staff" p="16877">
+<f n="libasprintf.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libasprintf.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.0.6.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libbz2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libexpat.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libexpat.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextlib-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextlib.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextpo.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextpo.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextsrc-0.19.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgettextsrc.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgio-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgio-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libglib-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libglib-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgmodule-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgmodule-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgobject-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgobject-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgthread-2.0.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libgthread-2.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.5.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libhistory.6.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libiconv.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libiconv.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libintl.8.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libintl.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="liblzma.5.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="liblzma.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libncurses.5.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcre.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcrecpp.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcrecpp.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcreposix.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libpcreposix.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.0.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.5.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.1.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.2.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.3.dylib" o="mdecorde" g="staff" p="33188"/>
+<f n="libreadline.6.dylib" o="mdecorde" g="staff" p="33188"/>
+</f>
+</f>
+</f>
+</pkg-contents>
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/INSTALL
===================================================================
--- tmp/org.txm.setups/shared/mac/INSTALL	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/INSTALL	(revision 1220)
@@ -1,5 +1,7 @@
 #!/bin/sh
 
+VERSION="-TXMVERSION"
+
 vercomp () {
     echo "test $1 $2"
     if [[ $1 == $2 ]]
@@ -71,7 +73,7 @@
 
 say $SAY_STARTINSTALL
 echo "** TXM postinstall: start post installation"
-TXMINSTALLDIR="/Applications/TXM"
+TXMINSTALLDIR="/Applications/TXM${VERSION}.app"
 
 # remove "try(library(textometrieR))" from .Rprofile if any
 if [ -f "$HOME/.Rprofile" ]; then
@@ -86,41 +88,35 @@
 
 say $SAY_INSTALLR
 if [ ! -d "/usr/local/lib/tcl8" ]; then
-	installer -pkg "$TXMINSTALLDIR/R/tcltk-8.5.5-x11.pkg" -allowUntrusted -target /
+	installer -pkg "$TXMINSTALLDIR/Contents/TXM/R/tcltk-8.5.5-x11.pkg" -allowUntrusted -target /
 	if [ $? != 0 ]; then
-			echo "** TXM install: installation of tcltk failed. Aborting."
-			exit 1;
+		echo "** TXM install: installation of tcltk failed. Aborting."
+		exit 1
 	fi
 else 
 	echo "Skipping tcl8 installation"
 fi
 
 if [ ! -d "/usr/local/share/texinfo" ]; then
-	installer -pkg "$TXMINSTALLDIR/R/texinfo-6.1-0.pkg" -allowUntrusted -target /
+	installer -pkg "$TXMINSTALLDIR/Contents/TXM/R/texinfo-6.1-0.pkg" -allowUntrusted -target /
 	if [ $? != 0 ]; then
-			echo "** TXM install: installation of texinfo failed. Aborting."
-			exit 1;
+		echo "** TXM install: installation of texinfo failed. Aborting."
+		exit 1
 	fi
 else 
-	echo "Skipping Texinfo installation"
+	echo "Skipping 'texinfo' installation"
 fi
 
 if [ ! -d "/opt/X11/bin" ]; then
-	installer -pkg "$TXMINSTALLDIR/R/XQuartz.pkg" -allowUntrusted -target /
+	installer -pkg "$TXMINSTALLDIR/Contents/TXM/R/XQuartz.pkg" -allowUntrusted -target /
 	if [ $? != 0 ]; then
-			echo "** TXM install: installation of XQuartz failed. Aborting."
-			exit 1;
+		echo "** TXM install: installation of XQuartz failed. Aborting."
+		exit 1
 	fi
 else 
-	echo "Skipping XQartz installation"
+	echo "Skipping XQuartz installation"
 fi
 
-tar xzf "$TXMINSTALLDIR/R/R.tar.gz" -C "$TXMINSTALLDIR/R"
-if [ $? != 0 ]; then
-		echo "** TXM install: failed to extract R binaries. Aborting."
-		exit 1;
-fi
-
 say $SAY_CREATESTAMP
 echo "** TXM postinstall: create STAMP file"
 # Create STAMP
@@ -134,11 +130,10 @@
 say $SAY_SETFILERIGHTS
 echo "** TXM postinstall: set rights"
 # Set executable files
-chmod -R +rx "$TXMINSTALLDIR/cwb/bin"
-chmod +x "$TXMINSTALLDIR"/TXM/plugins/CQP.macosx*/res/macosx/*
+chmod +x "$TXMINSTALLDIR"/Contents/TXM/plugins/CQP.macosx*/res/macosx/*
 
 chmod -R +r "$TXMINSTALLDIR"
-chmod +rx "$TXMINSTALLDIR/TXM.app/Contents/MacOS/TXM"
+chmod +rx "$TXMINSTALLDIR/Contents/MacOS/TXM"
 chmod -R +rx /opt/local/lib
 
 echo "sudo chown -R $USER $TXMINSTALLDIR"
Index: tmp/org.txm.setups/shared/mac/BUILDPKG.pkgproj
===================================================================
--- tmp/org.txm.setups/shared/mac/BUILDPKG.pkgproj	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/BUILDPKG.pkgproj	(revision 1220)
@@ -22,7 +22,7 @@
 									<key>GID</key>
 									<integer>80</integer>
 									<key>PATH</key>
-									<string>Applications/TXM</string>
+									<string>Applications/TXM-TXMVERSION.app</string>
 									<key>PATH_TYPE</key>
 									<integer>1</integer>
 									<key>PERMISSIONS</key>
@@ -463,11 +463,11 @@
 				<key>IDENTIFIER</key>
 				<string>org.txm</string>
 				<key>NAME</key>
-				<string>TXM</string>
+				<string>TXM-TXMVERSION</string>
 				<key>OVERWRITE_PERMISSIONS</key>
 				<false/>
 				<key>VERSION</key>
-				<string>0.8.0</string>
+				<string>TXMVERSION</string>
 			</dict>
 			<key>UUID</key>
 			<string>B3537FD7-A0A7-4961-A28B-1EF5E91B357D</string>
@@ -1483,7 +1483,7 @@
 				</dict>
 			</array>
 			<key>NAME</key>
-			<string>TXM_0.8.0_MacOSX_installer</string>
+			<string>TXM_TXMVERSION_MacOSX_installer</string>
 		</dict>
 	</dict>
 	<key>SHARED_GLOBAL_DATA</key>
Index: tmp/org.txm.setups/shared/mac/finish_en.txt
===================================================================
--- tmp/org.txm.setups/shared/mac/finish_en.txt	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/finish_en.txt	(revision 1220)
@@ -1,4 +1,4 @@
 
-You can start TXM with the 'TXM.app' file found in the "Applications" / "TXM" directory.
+You can start TXM with the "Applications" / "TXMTXMVERSION" app.
 
 If you want to automatically tag and lemmatize your corpora with the TreeTagger software during import, you need to follow additional installation instructions given in the "Help > Install TreeTagger" menu.
Index: tmp/org.txm.setups/shared/mac/CLEAN
===================================================================
--- tmp/org.txm.setups/shared/mac/CLEAN	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/CLEAN	(revision 1220)
@@ -1,9 +1,12 @@
 #!/bin/sh
-echo "** TXM preinstall: remove /Applications/TXM"
-if [ ! -f "/Applications/TXM" ]; then
-	sudo rm -rf /Applications/TXM
+
+VERSION="-TXMVERSION"
+
+echo "** TXM preinstall: remove /Applications/TXM${VERSION}.app"
+if [ ! -f "/Applications/TXM${VERSION}.app" ]; then
+	sudo rm -rf /Applications/TXM${VERSION}.app
 	if [ $? != 0 ];then
-		echo "** TXM preinstall: failed to delete /Applications/TXM"
+		echo "** TXM preinstall: failed to delete /Applications/TXM${VERSION}.app"
 		exit 1
 	fi
 fi
@@ -28,10 +31,18 @@
 	fi
 fi
 
-if [ ! -f "$HOME/TXM/.txm" ]; then
-	sudo rm -rf "$HOME/TXM/.txm"
+if [ ! -f "$HOME/TXM${VERSION}/.txm" ]; then
+	sudo rm -rf "$HOME/TXM${VERSION}/.txm"
 	if [ $? != 0 ];then
-		echo "** TXM preinstall: failed to delete $HOME/TXM/.txm"
+		echo "** TXM preinstall: failed to delete $HOME/TXM${VERSION}/.txm"
 		exit 1
 	fi
+fi
+
+if [ ! -f "$HOME/TXM${VERSION}/corpora/.metadata" ]; then
+	sudo rm -rf "$HOME/TXM${VERSION}/corpora/.metadata"
+	if [ $? != 0 ];then
+		echo "** TXM preinstall: failed to delete $HOME/TXM${VERSION}/corpora/.metadata"
+		exit 1
+	fi
 fi
\ No newline at end of file
Index: tmp/org.txm.setups/shared/mac/finish_fr.txt
===================================================================
--- tmp/org.txm.setups/shared/mac/finish_fr.txt	(revision 1219)
+++ tmp/org.txm.setups/shared/mac/finish_fr.txt	(revision 1220)
@@ -1,4 +1,4 @@
 
-TXM se lance par le fichier "TXM.app" situ� dans le r�pertoire "Applications" / "TXM".
+TXM se lance avec l'application "Applications" / "TXM".
 
 Si vous souhaitez �tiqueter et lemmatiser automatiquement vos corpus avec le logiciel TreeTagger lors de l'import, vous devez suivre les instructions d'installation suppl�mentaires fournies dans le menu "Aide > Installer TreeTagger".
Index: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/GetProxyConfiguration.jar
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/GetProxyConfiguration.jar
___________________________________________________________________
Added: svn:executable
   + *
Added: svn:mime-type
   + application/octet-stream

Index: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/TestPreInstall.jar
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/TestPreInstall.jar
___________________________________________________________________
Added: svn:mime-type
   + application/octet-stream

Index: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/YesNoDialog.jar
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/TXM/YesNoDialog.jar
___________________________________________________________________
Added: svn:mime-type
   + application/octet-stream

Index: tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/MacOS/TXM
===================================================================
--- tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/MacOS/TXM	(revision 0)
+++ tmp/org.txm.setups/shared/mac/Applications/TXM.app/Contents/MacOS/TXM	(revision 1220)
@@ -0,0 +1,186 @@
+#!/bin/sh
+# This script launch TXM in the right directory and with the right TXM.ini file
+
+echo "Prepare redirections in $HOME/TXMPostInstallOutputLogs.txt and $HOME/TXMPostInstallErrorLogs.txt files"
+
+LOGFILESMSG=", see $HOME/TXMPostInstallOutputLogs.txt and $HOME/TXMPostInstallErrorLogs.txt output and error messages files."
+VERSION=0.8.0
+exec 3>$HOME/TXMPostInstallOutputLogs.txt
+exec 4>$HOME/TXMPostInstallErrorLogs.txt
+
+echo "$HOME is '$HOME'"
+
+if [ ! -d "$HOME" ]; then
+	echo "TXM: Impossible to access user home directory ($HOME). Aborting"
+	exit 1
+fi
+
+echo "Creating all necessary directories"
+
+TXMHOME="$HOME/TXM_$VERSION"
+echo "TXMHOME='$TXMHOME'"
+if [ ! -d "$TXMHOME" ]; then
+	mkdir "$TXMHOME"
+fi
+if [ ! -d "$TXMHOME" ]; then
+	zenity --info --text="TXM: Impossible to access '$TXMHOME' directory. Aborting$LOGFILESMSG"
+	echo "TXM: Impossible to access '$DIR' directory. Aborting$LOGFILESMSG"
+	exit 1
+fi
+
+DIR="$TXMHOME/.txm"
+echo "DIR='$DIR'"
+if [ ! -d "$DIR" ]; then
+	mkdir "$DIR"
+fi
+if [ ! -d "$DIR" ]; then
+	zenity --info --text="TXM: Impossible to access '$DIR' directory. Aborting$LOGFILESMSG"
+	echo "TXM: Impossible to access '$DIR' directory. Aborting$LOGFILESMSG"
+	exit 1
+fi
+LOGFILES=", see log files $HOME/TXMPostInstallLogs.txt and $HOME/TXMPostInstallErrorLogs.txt."
+
+vercomp () {
+    echo "test $1 $2"
+    if [[ $1 == $2 ]]
+    then
+        return 0
+    fi
+    local IFS=.
+    local i ver1=($1) ver2=($2)
+    # fill empty fields in ver1 with zeros
+    for ((i=${#ver1[@]}; i<${#ver2[@]}; i++))
+    do
+        ver1[i]=0
+    done
+    for ((i=0; i<${#ver1[@]}; i++))
+    do
+        if [[ -z ${ver2[i]} ]]
+        then
+            ver2[i]=0
+        fi
+        if ((10#${ver1[i]} > 10#${ver2[i]}))
+        then
+            return 0
+        fi
+        if ((10#${ver1[i]} < 10#${ver2[i]}))
+        then
+            return 1
+        fi
+    done
+    return 0
+}
+
+
+echo "TXM: looking at the last TXM install date from the /usr/lib/TXM/STAMP file"
+
+if [ ! -f "/Applications/TXM-TXMVERSION.app/STAMP" ]; then
+	echo "TXM: Impossible to access '/Applications/TXM-TXMVERSION.app/STAMP' file. Aborting$LOGFILESMSG"
+	exit 1
+fi
+
+STAMP=`stat -t %Y%m%d "/Applications/TXM-TXMVERSION.app/STAMP" | cut -d\  -f11`
+
+if [ $? != 0 ]; then
+    echo "TXM: Can't find STAMP file /Applications/TXM-TXMVERSION.app/STAMP $LOGFILES"
+    exit 1 ;
+fi
+
+echo "TXM: if .txm folder does not contain the STAMP file, its a new install."
+if [ ! -e "$TXMHOME/.txm/$STAMP" ]; then
+
+	echo "New TXM install: it's the first launch after the installation"
+	if [ -f "/tmp/org.txm.rcpapplication.prefs" ]; then
+		rm -f "/tmp/org.txm.rcpapplication.prefs" # remove previous preference files if any
+	fi
+
+	echo "Backing up previous TXM 0.7.6 preferences if any..."
+	if [ -f "$HOME/.txm/configuration/.settings/org.txm.rcpapplication.prefs" ]; then
+		echo "Found preference file: $HOME/.txm/configuration/.settings/org.txm.rcpapplication.prefs"
+		cp -f "$HOME/.txm/configuration/.settings/org.txm.rcpapplication.prefs" "/tmp/org.txm.rcpapplication.prefs"
+		if [ $? != 0 ]; then
+  			echo "Failed to copy old preference file in /tmp/org.txm.rcpapplication.prefs"
+		fi
+	fi
+
+	echo "Backing up previous TXM 0.7.7 preferences if any..."
+	if [ -f "$HOME/.txm/data/.metadata/.plugins/org.eclipse.core.runtime/.settings/org.txm.rcpapplication.prefs" ]; then
+		echo "Found preference file: $HOME/.txm/data/.metadata/.plugins/org.eclipse.core.runtime/.settings/org.txm.rcpapplication.prefs"
+		cp -f "$HOME/.txm/data/.metadata/.plugins/org.eclipse.core.runtime/.settings/org.txm.rcpapplication.prefs" "/tmp/org.txm.rcpapplication.prefs"
+		if [ $? != 0 ]; then
+  			echo "Failed to copy old preference file in /tmp/org.txm.rcpapplication.prefs"
+		fi
+	fi
+
+	echo "TXM: Installing up to date TXM directories."
+	rm -rf "$TXMHOME/.txm"
+	if [ -d "$TXMHOME/.txm" ]; then
+	    zenity --info --text="TXM: Failed to remove $TXMHOME/.txm directory$LOGFILESMSG"
+	    echo "TXM: Failed to remove $TXMHOME/.txm directory$LOGFILESMSG"
+	    exit 1 ;
+	fi
+
+    mkdir "$TXMHOME/.txm"
+	mkdir "$TXMHOME/.txm/user"
+	mkdir "$TXMHOME/.txm/data"
+
+    if [ ! -d "$TXMHOME/.txm" ]; then
+		echo "TXM: Impossible to access '$TXMHOME/.txm' directory. Aborting$LOGFILESMSG"
+		exit 1
+    fi
+
+    echo "TXM: getting '/Applications/TXM-TXMVERSION.app/TXM.ini' and set write permission of '$TXMHOME/.txm/TXM.ini'"
+    cp "/Applications/TXM-TXMVERSION.app/Contents/TXM/TXM.ini" "$TXMHOME/.txm/TXM.ini" &&
+    chmod +w "$TXMHOME/.txm/TXM.ini";
+    
+    if [ $? != 0 ]; then
+       	echo "TXM: Can't launch TXM: failed to set TXM.ini file$LOGFILESMSG"
+        exit 1
+    fi
+
+    echo "TXM: creating the $TXMHOME/.txm/$STAMP install STAMP file."
+    touch "$TXMHOME/.txm/$STAMP"
+
+    if [ $? != 0 ]; then
+		echo "TXM: Can't launch TXM: failed to create the $TXMHOME/.txm/$STAMP install STAMP file$LOGFILESMSG"
+        exit 1
+    fi
+fi
+
+#) 1>&3 2>&4
+
+# don't exec TXM if problem occurs
+if [ $? != 0 ]; then
+    echo "TXM: An error occurred. Aborting$LOGFILESMSG";
+    exit 1 ;
+fi
+
+TXMINIARGSVM=""
+TXMINIARGS=""
+STARTVMARGS=0
+while read i ; do 	
+	if [ $STARTVMARGS == 1 ]; then
+ 		TXMINIARGSVM="$TXMINIARGSVM $i" ;
+	else
+		TXMINIARGS="$TXMINIARGS $i" ;
+	fi
+	
+	if [ $i == "-vmargs" ]; then
+ 	   STARTVMARGS=1
+	fi
+done < "$TXMHOME/.txm/TXM.ini"; 
+
+echo "TXM INI ARGS = $TXMINIARGS"
+echo "TXM INI VM ARGS = $TXMINIARGSVM"
+
+OSVERSION=`sw_vers -productVersion`
+
+vercomp $OSVERSION "10.7"
+
+#if [ $? != 0 ];then
+#	echo "TXM: Running TXM for Mac OS X $OSVERSION with the binary launcher..."
+#	open "/Applications/TXM-TXMVERSION.app" --args -run --launcher.ini "$TXMHOME/.txm/TXM.ini" -data "$TXMHOME/.txm/data" -user "$TXMHOME/.txm/user" -install "/Applications/TXM-TXMVERSION.app" &
+#else
+	echo "TXM: Running TXM for Mac OS X $OSVERSION with the JAR launcher..."
+	/Applications/TXM-TXMVERSION.app/Contents/TXM/jre/Contents/Home/bin/java -Djava.library.path="$(echo  /Applications/TXM-TXMVERSION.app/Contents/TXM/plugins/org.eclipse.equinox.launcher.cocoa.macosx.x86_64_*/eclipse_*.so)" -XX:MaxPermSize=256m -XstartOnFirstThread $TXMINIARGSVM -jar "$(echo /Applications/TXM-TXMVERSION.app/Contents/TXM/plugins/org.eclipse.equinox.launcher_*.jar)" -os macosx -ws cocoa -arch x86_64 -showsplash -run -data "$TXMHOME/corpora" -user "$TXMHOME/.txm/user" -install "/Applications/TXM-TXMVERSION.app/Contents/TXM"
+#fi
\ No newline at end of file
Index: tmp/org.txm.rcp.feature/win/TXM.bat
===================================================================
--- tmp/org.txm.rcp.feature/win/TXM.bat	(revision 1219)
+++ tmp/org.txm.rcp.feature/win/TXM.bat	(revision 1220)
@@ -73,7 +73,7 @@
 
 (
 set _JAVA_OPTIONS=-Duser.home="%USERHOME%"
-echo running "%installdir%TXM.exe" -run --launcher.ini "%DOTTXM%TXM.ini" -data "%DOTTXM%data" -user "%DOTTXM%user" -install "%installdir%"
+echo running "%installdir%TXM.exe" -run --launcher.ini "%DOTTXM%TXM.ini" -data "%DOTTXM%data" -user "%DOTTXM%user" -install "%installdir%"echo running "%installdir%TXM.exe" -log -run --launcher.ini "%DOTTXM%TXM.ini" -consolelog -clean -debug -console -noexit -data "%TXMHOME%corpora" -user "%DOTTXM%user" -install "%installdir%\"
 REM "%installdir%TXM.exe" -run --launcher.ini "%DOTTXM%TXM.ini" -data "%DOTTXM%corpora" -user "%DOTTXM%user" -install "%installdir%"
 "%installdir%TXM.exe" -log -run --launcher.ini "%DOTTXM%TXM.ini" -consolelog -clean -debug -console -noexit -data "%TXMHOME%corpora" -user "%DOTTXM%user" -install "%installdir%\"
 ) >"%TXMHOME%TXMOutputLogs.txt" 2>"%TXMHOME%TXMErrorLogs.txt" 

Property changes on: tmp/org.txm.rcp.feature/mac/jre
___________________________________________________________________
Added: svn:ignore
   + **


Index: tmp/org.txm.setups/BuildMacOSXIntel.sh
===================================================================
--- tmp/org.txm.setups/BuildMacOSXIntel.sh	(revision 1219)
+++ tmp/org.txm.setups/BuildMacOSXIntel.sh	(revision 1220)
@@ -1,9 +1,11 @@
 version=`cat VERSION`
+subversion=`cat SUBVERSION`
+fullversion="${version}${subversion}"
 STEP=$1
 
-rm -f "TXM_${version}_MacOSX.tar.gz"
-rm -rf "TXM_${version}_MacOSX"
-mkdir "TXM_${version}_MacOSX"
+rm -f "TXM_${fullversion}_MacOSX.tar.gz"
+rm -rf "TXM_${fullversion}_MacOSX"
+mkdir "TXM_${fullversion}_MacOSX"
 
 # ensure INSTALL CLEAN file rights
 chmod 775 shared/mac/INSTALL shared/mac/CLEAN
@@ -13,26 +15,26 @@
 fi
 
 echo " copy mac shared files: R"
-rsync -r  --exclude '.svn' shared/mac/* "TXM_${version}_MacOSX"
+rsync -r  --exclude '.svn' shared/mac/* "TXM_${fullversion}_MacOSX"
 if [ $? != 0 ]; then
 	echo "** MacOSXIntel.sh : failed to copy Mac shared files"
 	exit 1;
 fi
 
 echo " copy shared files: css, xsl, scripts, samples..."
-rsync -r  --exclude '.svn' shared/all/* "TXM_${version}_MacOSX/Applications/TXM"
+rsync -r  --exclude '.svn' shared/all/* "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents/TXM"
 if [ $? != 0 ]; then
 	echo "** MacOSXIntel.sh : failed to copy shared files"
 	exit 1;
 fi
 
-echo "convert licence files encoding to MacRoman"
-iconv -f utf8 -t MAC shared/all/license_agreement_fr.txt > "TXM_${version}_MacOSX/Applications/TXM/license_agreement_fr.txt"
-iconv -f utf8 -t MAC shared/all/license_agreement.txt > "TXM_${version}_MacOSX/Applications/TXM/license_agreement.txt"
-iconv -f utf8 -t MAC shared/all/LICENSE_FR.TXT > "TXM_${version}_MacOSX/Applications/TXM/LICENSE_FR.TXT"
-iconv -f utf8 -t MAC shared/all/LICENSE.TXT > "TXM_${version}_MacOSX/Applications/TXM/LICENSE.TXT"
+echo " convert licence files encoding to MacRoman"
+iconv -f utf8 -t MAC shared/all/license_agreement_fr.txt > "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents/TXM/license_agreement_fr.txt"
+iconv -f utf8 -t MAC shared/all/license_agreement.txt > "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents/TXM/license_agreement.txt"
+iconv -f utf8 -t MAC shared/all/LICENSE_FR.TXT > "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents/TXM/LICENSE_FR.TXT"
+iconv -f utf8 -t MAC shared/all/LICENSE.TXT > "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents/TXM/LICENSE.TXT"
 
-echo "remove parasite settings"
+echo " remove parasite settings"
 rm -f "exportRCP/macosx.cocoa.x86_64/TXM/p2/org.eclipse.equinox.p2.engine/.settings/*" &&
 rm -f "exportRCP/macosx.cocoa.x86_64/TXM/p2/org.eclipse.equinox.p2.engine/profileRegistry/profile.profile/.data/.settings/*"
 if [ $? != 0 ]; then
@@ -40,52 +42,65 @@
 	exit 1;
 fi
 
-echo "copy eclipse build files"
-rsync -r  --exclude '.svn' "../../CQP.macosx/res/macosx"/* "TXM_${version}_MacOSX/Applications/TXM/cwb/bin" &&
-chmod -R +x "TXM_${version}_MacOSX/Applications/TXM/cwb/bin"
-if [ $? != 0 ]; then
-	echo "** MacOSXIntel.sh : failed to copy CQP.macosx plugin files"
-	exit 1;
+echo " rename TXM eclipse launcher"
+if [ ! -f  "exportRCP/macosx.cocoa.x86_64/MacOS/launcher" ]; then
+
+	mv "exportRCP/macosx.cocoa.x86_64/MacOS/TXM" "exportRCP/macosx.cocoa.x86_64/MacOS/launcher"
+	if [ $? != 0 ]; then
+		echo "** MacOSXIntel.sh : failed to binaries files"
+		exit 1;
+	fi
 fi
 
 echo " copy eclipse arch dependent build"
-rsync -r  --exclude '.svn' "exportRCP/macosx.cocoa.x86_64/TXM" "TXM_${version}_MacOSX/Applications/TXM"
+rsync -r  --exclude '.svn' "exportRCP/macosx.cocoa.x86_64/"* "TXM_${fullversion}_MacOSX/Applications/TXM.app/Contents"
 if [ $? != 0 ]; then
 	echo "** MacOSXIntel.sh : failed to binaries files"
 	exit 1;
 fi
 
-chmod +x "TXM_${version}_MacOSX/INSTALL" &&
-chmod +x "TXM_${version}_MacOSX/CLEAN"
+chmod +x "TXM_${fullversion}_MacOSX/INSTALL" &&
+chmod +x "TXM_${fullversion}_MacOSX/CLEAN"
 if [ $? != 0 ]; then
 	echo "** MacOSXIntel.sh : failed to chmod +x INSTALL & CLEAN files"
 	exit 1;
 fi
 
-mv "TXM_${version}_MacOSX/Applications/TXM/TXM.app" "TXM_${version}_MacOSX/Applications/TXM/.main.app"
-if [ $? != 0 ]; then
-	echo "** MacOSXIntel.sh : failed to hide TXM.app"
-	exit 1;
-fi
-
 #echo "set LSUIElement to 1"
-#find ./TXM_${version}_MacOSX/Applications/TXM/.main.app/Contents/Info.plist -type f -exec sed -i 's/<dict>/<dict><key>LSUIElement<\/key><string>1<\/string>/g' {} \;
+#find ./TXM_${fullversion}_MacOSX/Applications/TXM.app/.main.app/Contents/Info.plist -type f -exec sed -i 's/<dict>/<dict><key>LSUIElement<\/key><string>1<\/string>/g' {} \;
 #if [ $? != 0 ]; then
 #	echo "** MacOSXIntel.sh : failed to fix Info.plist"
 #	exit 1;
 #fi
 
 echo " clean"
-bash directoryCleaner.sh "TXM_${version}_MacOSX"
+bash directoryCleaner.sh "TXM_${fullversion}_MacOSX"
 if [ $? != 0 ]; then
-	echo "** $APP: failed to clean mac setup TXM_${version}_MacOSX"
+	echo "** $APP: failed to clean mac setup TXM_${fullversion}_MacOSX"
 	exit 1;
 fi
 
-echo "Tar gz TXM_${version}_MacOSX"
-tar -zcf "TXM_${version}_MacOSX.tar.gz" TXM_${version}_MacOSX
+echo " search&replace in files TXMVERSION"
+find "TXM_${fullversion}_MacOSX/CLEAN" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/finish_en.txt" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/INSTALL" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/01applications.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/02opt-contents.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/02rlibs-contents.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/02rlibs.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/03opt-contents.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/03rlibs-contents.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pmdoc/index.xml" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/BUILDPKG.pkgproj" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+find "TXM_${fullversion}_MacOSX/Applications/TXM.app" -type f -exec sed -i "s/TXMVERSION/$fullversion/g" {} \;
+
+echo " rename files to add version=$version"
+mv "TXM_${fullversion}_MacOSX/Applications/TXM.app" "TXM_${fullversion}_MacOSX/Applications/TXM-${fullversion}.app"
+
+echo "Tar gz TXM_${fullversion}_MacOSX"
+tar -zcf "TXM_${fullversion}_MacOSX.tar.gz" "TXM_${fullversion}_MacOSX"
 if [ $? != 0 ]; then
-	echo "** MacOSXIntel.sh : failed to tar gz TXM_${version}_MacOSX"
+	echo "** MacOSXIntel.sh : failed to tar gz TXM_${fullversion}_MacOSX"
 	exit 1;
 fi
 
@@ -93,15 +108,15 @@
 	echo "Local test: The archive is not sent to shared files."
 else
 	echo "Sending to ensldfs.ens-lyon.fr/services/labo_ana_corpus/PartageTemp"
-	smbclient -A auth.txt "//ensldfs.ens-lyon.fr/services" -c "cd \"/Laboratoires/labo_ana_corpus/Projets/Textométrie/Logiciel/TXM/$STEP\" ; put TXM_${version}_MacOSX.zip ; exit"
+	smbclient -A auth.txt "//ensldfs.ens-lyon.fr/services" -c "cd \"/Laboratoires/labo_ana_corpus/Projets/Textométrie/Logiciel/TXM/$STEP\" ; put TXM_${fullversion}_MacOSX.zip ; exit"
 	if [ $? != 0 ]; then
-		echo "** MacOSXIntel.sh : failed to send TXM_${version}_MacOSX to labo_ana_corpus"
+		echo "** MacOSXIntel.sh : failed to send TXM_${fullversion}_MacOSX to labo_ana_corpus"
 		exit 1;
 	fi
 fi
 
-#cp "TXM_${version}_MacOSX.tar.gz" /run/user/1001/gvfs/smb-share\:server\=ensldfs.ens-lyon.fr\,share\=services\,user\=$USER/Laboratoires/labo_ana_corpus/PartageTemp
+#cp "TXM_${fullversion}_MacOSX.tar.gz" /run/user/1001/gvfs/smb-share\:server\=ensldfs.ens-lyon.fr\,share\=services\,user\=$USER/Laboratoires/labo_ana_corpus/PartageTemp
 #if [ $? != 0 ]; then
 #	echo "** $APP: TXM_${version}_MacOSX.tar.gz not copied PartageTemp"
 #	exit 1;
 #fi
@@ -93,15 +108,15 @@
 #if [ $? != 0 ]; then
-#	echo "** $APP: TXM_${version}_MacOSX.tar.gz not copied PartageTemp"
+#	echo "** $APP: TXM_${fullversion}_MacOSX.tar.gz not copied PartageTemp"
 #	exit 1;
 #fi
Index: tmp/org.txm.rcp.feature/mac/R/texinfo-6.1-0.pkg
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.rcp.feature/mac/R/texinfo-6.1-0.pkg
___________________________________________________________________
Added: svn:mime-type
   + application/octet-stream

Index: tmp/org.txm.rcp.feature/mac/R/XQuartz.pkg
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.rcp.feature/mac/R/XQuartz.pkg
___________________________________________________________________
Added: svn:mime-type
   + application/octet-stream

Index: tmp/org.txm.rcp.feature/mac/R/tcltk-8.5.5-x11.pkg
===================================================================
Cannot display: file marked as a binary type.
svn:mime-type = application/octet-stream

Property changes on: tmp/org.txm.rcp.feature/mac/R/tcltk-8.5.5-x11.pkg
___________________________________________________________________
Added: svn:mime-type
   + application/octet-stream

